update link to upper-constraints.txt
[modeling/etsicatalog.git] / run.sh
diff --git a/run.sh b/run.sh
index a0bbe64..410f26c 100755 (executable)
--- a/run.sh
+++ b/run.sh
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-logDir="/var/log/onap/modeling/genericparser/"
+logDir="/var/log/onap/modeling/etsicatalog/"
 if [ ! -x  $logDir  ]; then
     mkdir -p $logDir
 fi
 
-nohup python manage.py runserver 0.0.0.0:8806 > /dev/null &
-# nohup uwsgi --http :8806 -t 120 --module genericparser.wsgi --master --processes 4 &
+nohup python manage.py runserver 0.0.0.0:8806 > /dev/null &
+# nohup uwsgi --http :8806 -t 120 --module catalog.wsgi --master --processes 4 &
 
-
-# if [ "${SSL_ENABLED}" = "true" ]; then
-#     nohup uwsgi --https :8806,genericparser/pub/ssl/cert/foobar.crt,genericparser/pub/ssl/cert/foobar.key, -t 120 --module genericparser.wsgi --master --processes 4 &
-# else
-#     nohup uwsgi --http :8806 -t 120 --module genericparser.wsgi --master --processes 4 &
-# fi
+if [ "${SSL_ENABLED}" = "true" ]; then
+   nohup uwsgi --https :8806,catalog/pub/ssl/cert/foobar.crt,catalog/pub/ssl/cert/foobar.key, -t 120 --enable-threads --module catalog.wsgi --master --processes 4 &
+else
+   nohup uwsgi --http :8806 -t 120 --enable-threads --module catalog.wsgi --master --processes 4 &
+fi